@@ -9,9 +9,17 @@
 -------------------------------------------------
 """
 
+import os
+SNIPPETS_ENV = os.environ.get("SNIPPETS_ENV", "prod")
+
+
+from snippets.perf import *
+from snippets.logs import *
+from snippets.decorators import *
 from snippets.utils import *
-from snippets.decorators import *
+from snippets.mixin import *
+from snippets.eval import *
+
 
-__version__ = "0.0.11"
 logging.basicConfig(level=logging.INFO, format="%(asctime)s [%(levelname)s][%(filename)s:%(lineno)d]:%(message)s",
                     datefmt='%Y-%m-%d %H:%M:%S')
